@@ -113,6 +113,7 @@ def counting_candles(data= None, threshold = 1., contravariant = -1, **kwargs):
     else :
         return -contravariant
 
+
 def dd_threshold(data = None, threshold=1., contravariant = -1., **kwargs):
     ratio = data['high'][-1]/data['high'][0]
     if ratio > threshold:
@@ -128,21 +129,51 @@ def lead_lag_indicator(data = None, lead=3, lag=5, contravariant = -1., **kwargs
     else :
         return contravariant
 
-def volume_weighted_high_low_vol(data = None , vol_threshold = 0.05, up_trend_threshold=1e-4, low_trend_threshold=1e-4, contravariant = 1., display = False, **kwargs):
-    trend = ((data['close'][-1]-data['close'][0])/data['close'][0])/data['close'][0]
-    data['hl'] = (data['high'] - data['low'])/data['low']
-    data['volu_hi_low'] = data['volumefrom']*data['hl']
-    weighted_volu_hi_low = data['volu_hi_low'].sum() / data['volumefrom'].sum()
-    if display:
-        print('weighted_volu_hi_low :' + str(weighted_volu_hi_low))
-        print('trend :'+str(trend))
-        print('vol_threshold :'+str(vol_threshold))
-        print('up_trend_threshold :'+str(up_trend_threshold))
-        print('low_trend_threshold :'+str(low_trend_threshold))
-    if weighted_volu_hi_low > vol_threshold:
-        if trend > up_trend_threshold:
+def volume_weigthed_high_low_vol_perc(data = None, vol_threshold = 0.8, up_trend_threshold=0.8, low_trend_threshold=0.2, contravariant = -1., lag = 2, **kwargs):
+    ## aggregating the volumes by lag
+    all_indices = list(reversed(range(len(data) - 1, 0, -lag)))
+    data['aggregated_indice'] = np.nan
+    data['aggregated_indice'].loc[all_indices] = all_indices
+    data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
+    data['aggregated_indice'] = data['aggregated_indice'].astype(int)
+    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    high = data.groupby(['aggregated_indice'])['high'].agg('max')
+    low = data.groupby(['aggregated_indice'])['low'].agg('min')
+
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
+    data['aggregated_high'] =  data['aggregated_high'].map(high)
+    data['aggregated_low'] =  data['aggregated_low'].map(low)
+
+    data = data[::,-lag]
+    data = data.iloc[::-1]
+
+    data['hl'] = (data['aggregated_high'] - data['aggregated_low'])/data['aggregated_low']
+    data['volu_hi_low'] = data['aggregated_volume']*data['hl']
+
+    data['close_ret']=data['close'].pct_change()
+
+
+    data['volu_hi_low_pct_rank'] = data['volu_hi_low'].rank(pct=True)
+    data['close_ret_pct_rank'] = data['close_ret'].rank(pct=True)
+
+    trend_rank = data['close_ret_pct_rank'][-1]
+    vol_rank = data['volu_hi_low_pct_rank'][-1]
+
+
+    # #trend over the all lookback period
+    # trend = ((data['close'][-1]-data['close'][0])/data['close'][0])
+    # # vol over the all lookback_period
+    # weighted_volu_hi_low = data['volu_hi_low'].sum() / data['volumefrom'].sum()
+    #
+    #
+    # #trend over the lagging period
+    # trend_lag = ((data['close'][-1]-data['close'][-1])/data['close'][-1])
+    # weighted_volu_hi_low_lag = data['volu_hi_low'][-1]/ data['volumefrom'][-1]
+    #
+    if vol_rank > vol_threshold:
+        if trend_rank > up_trend_threshold:
             return contravariant
-        elif trend < -low_trend_threshold:
+        elif trend_rank < low_trend_threshold:
             return -contravariant
         else:
             return np.nan
@@ -150,28 +181,6 @@ def volume_weighted_high_low_vol(data = None , vol_threshold = 0.05, up_trend_th
         return np.nan
 
 
-def volume_weighted_high_low_vol_long_only(data = None , vol_threshold = 0.05, up_trend_threshold=1e-4, low_trend_threshold=1e-4, contravariant = 1., display = False, **kwargs):
-    trend = ((data['close'][-1]-data['close'][0])/data['close'][0])/data['close'][0]
-    data['hl'] = (data['high'] - data['low'])/data['low']
-    data['volu_hi_low'] = data['volumefrom']*data['hl']
-    weighted_volu_hi_low = data['volu_hi_low'].sum() / data['volumefrom'].sum()
-    if display:
-        print('weighted_volu_hi_low :' + str(weighted_volu_hi_low))
-        print('trend :'+str(trend))
-        print('vol_threshold :'+str(vol_threshold))
-        print('up_trend_threshold :'+str(up_trend_threshold))
-        print('low_trend_threshold :'+str(low_trend_threshold))
-    if weighted_volu_hi_low > vol_threshold:
-        if trend > up_trend_threshold:
-            return contravariant
-        elif trend < -low_trend_threshold:
-            return 0
-        else:
-            return np.nan
-    else :
-        return np.nan
-
-
 
 def slope_induced(data = None, slope_column = 'high', contravariant = -1., **kwargs):
     high_slope = (data[slope_column][-1] - data[slope_column][0]) / len(data)
